#
# spec file for package ksysguard5
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without lang
Name:           ksysguard5
Version:        5.22.0
Release:        3.4
# Full Plasma 5 version (e.g. 5.8.95)
%{!?_plasma5_bugfix: %define _plasma5_bugfix %{version}}
# Latest ABI-stable Plasma (e.g. 5.8 in KF5, but 5.8.95 in KUF)
%{!?_plasma5_version: %define _plasma5_version %(echo %{_plasma5_bugfix} | awk -F. '{print $1"."$2}')}
Summary:        KDE System Guard daemon
License:        GPL-2.0-only
Group:          System/GUI/KDE
URL:            http://www.kde.org
Source:         ksysguard-%{version}.tar.xz
%if %{with lang}
Source1:        ksysguard-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
Source3:        ksysguardd.service
# PATCH-FIX-OPENSUSE 0001-Use-run-for-ksysguardd-s-pid-file.patch
Patch0:         0001-Use-run-for-ksysguardd-s-pid-file.patch
# PATCH-FIX-UPSTREAM
Patch1:         0001-lmsensors-Fix-buffer-size-passed-to-snprintf.patch
BuildRequires:  extra-cmake-modules >= 5.81.0
BuildRequires:  kf5-filesystem
%ifnarch s390 s390x
BuildRequires:  libsensors4-devel
%endif
BuildRequires:  systemd-rpm-macros
BuildRequires:  xz
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5DBusAddons)
BuildRequires:  cmake(KF5DocTools)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5IconThemes)
BuildRequires:  cmake(KF5Init)
BuildRequires:  cmake(KF5ItemViews)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5NewStuff)
BuildRequires:  cmake(KF5Notifications)
BuildRequires:  cmake(KF5SysGuard) >= %{_plasma5_version}
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  cmake(Qt5Core) >= 5.15
BuildRequires:  cmake(Qt5Widgets)
# kde#421514
BuildRequires:  cmake(Qt5Test)
Recommends:     %{name}-lang
Requires:       libksysguard5-plugins
BuildRequires:  update-desktop-files
Provides:       kdebase4-workspace-ksysguardd = %{version}
Obsoletes:      kdebase4-workspace-ksysguardd < %{version}
%{systemd_ordering}

%description
This package contains the ksysguard daemon and application.

This package can be installed on servers without any other KDE packages
to enable monitoring them remotely with ksysguard.

%lang_package

%prep
%autosetup -p1 -n ksysguard-%{version}

%build
  %cmake_kf5 -d build -- -DCMAKE_INSTALL_LOCALEDIR=%{_kf5_localedir}
  %cmake_build

%install
  %kf5_makeinstall -C build
%if %{with lang}
  %kf5_find_lang
  %kf5_find_htmldocs
%endif
  %suse_update_desktop_file    org.kde.ksysguard      System Monitor

  install -D -m 0644 %{SOURCE3} %{buildroot}%{_unitdir}/ksysguardd.service

%pre
%service_add_pre ksysguardd.service

%preun
%service_del_preun ksysguardd.service

%post
%service_add_post ksysguardd.service

%postun
%service_del_postun ksysguardd.service

%files
%license COPYING*
%{_kf5_bindir}/ksysguard
%{_kf5_bindir}/ksysguardd
%config %{_kf5_sysconfdir}/ksysguarddrc
%{_kf5_knsrcfilesdir}/ksysguard.knsrc
%{_kf5_applicationsdir}/org.kde.ksysguard.desktop
%{_kf5_notifydir}/
%dir %{_kf5_htmldir}/en
%dir %{_kf5_htmldir}
%{_kf5_htmldir}/en/ksysguard/
%{_kf5_iconsdir}/hicolor/*/*/
%{_kf5_sharedir}/ksysguard/
%{_kf5_sharedir}/kxmlgui5/
%{_kf5_appstreamdir}/org.kde.ksysguard.appdata.xml
%{_unitdir}/ksysguardd.service

%if %{with lang}
%files lang -f %{name}.lang
%endif

%changelog
* Sat Jun 18 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix crash with _FORTIFY_SOURCE=3 (boo#1200656):
  * 0001-lmsensors-Fix-buffer-size-passed-to-snprintf.patch
* Sat Jun 26 2021 Fabian Vogt <fabian@ritter-vogt.de>
- s390 has no libsensors
* Sat Jun  5 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.0
- Changes since 5.21.90:
  * new release
* Thu May 13 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.90
  * New feature release, no more part of Plasma
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.90
- Too many changes to list here
* Tue May  4 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.5
- No code changes since 5.21.4
* Tue Apr  6 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.4
- No code changes since 5.21.3
* Tue Mar 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.3
- Changes since 5.21.2:
  * Add missing #include <array> (kde#433517)
  * Add providerName to power plugin
  * Use correct unit for charge rate
* Tue Mar  2 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.2
- No code changes since 5.21.1
* Tue Feb 23 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.1
- Changes since 5.21.0:
  * Force device statistics refresh rate to be always one second (kde#433063)
* Mon Feb 15 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.0
- Changes since 5.20.90:
  * Fix sensors names of aggregate disk rates (kde#432851)
  * Fix copy paste error resulting in total upload displaying the upload rate (kde#430676)
  * Fix disk speeds (kde#432637)
  * Check if we could open a file
  * Include StorageVolumes by default
  * Set name for temperature sensor
  * cmake: add URL to help packagers
* Thu Jan 21 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/20.90/
- Too many changes to list here
* Tue Jan  5 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.5
- No code changes since 5.20.4
* Tue Dec  1 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.4
- No code changes since 5.20.3
* Wed Nov 11 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.3
- Changes since 5.20.2:
  * Stop the daemon if we have no client (kde#427204)
  * Do not load multiple versions of the same plugin
  * Only look for libnl
* Tue Oct 27 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.2
- No code changes since 5.20.1
* Tue Oct 20 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.1
- Changes since 5.20.0:
  * Divide network speeds by 2
* Thu Oct  8 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.0
- Changes since 5.19.90:
  * Set correct unit for "all/read" and "all/write" disk usage sensors
* Thu Sep 17 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.90
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.90
- Too many changes to list here
* Tue Sep  1 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.5
- Changes since 5.19.4:
  * [ksgrd] Correctly handle monitors list changing
* Tue Jul 28 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.4
- No code changes since 5.19.3
* Tue Jul  7 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.3
- No code changes since 5.19.2
* Tue Jun 23 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.2
- No code changes since 5.19.1
* Tue Jun 16 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.19.1.php
- Changes since 5.19.0.1:
  * Add units to disk/all/{read,write} (kde#422643,kde#422644)
* Wed Jun 10 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.0.1
  * New bugfix release
- Changes since 5.19.0:
  * Use new name for dbus interface too
  * Don't prefix value output with mount point
* Thu Jun  4 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.19.0.php
- Changes since 5.18.90:
  * Rename binary kstats as it causes a conflict with other packages (kde#421532)
  * Fix the user message: it is allocated, not used
  * ksysguardiface: Also exlude table and listview types from exposed sensors
  * ksgrdiface: Revert change to "All" strings
  * ksgrdiface: Use translated strings from KSysGuard::SysGuard library
  * Add proper names for containers/objects created by ksgrdinterface plugin
  * Add sensorinfo for sensorcontainers and sensorobjects
  * Cleanup indentation
  * Skip loading a plugin if it was already loaded
  * Fix Messages.sh v2
  * Fix Messages.sh
  * Only build autotests when enabled
  * Prefix disk name on size labels (kde#421513)
* Thu May 14 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.90.php
- Changes since 5.18.5:
  * Fix translation domain for ksysguard plugins
  * Exclude all loop devices from partition and disk sensors
  * Add context to translated strings and clarify some strings
  * Use KSysGuard namespace for KSysGuard targets
  * Add a new daemon for stats monitoring
  * Remove too strict Qt/KF5 deprecation rule
  * Add some new battery sensors : energy_now, energy_full and power_now.
  * bump to require Qt 5.14
  * Add per-partition total and all partitions sensors
  * Add support for power sensors from lm-sensors
  * Make it compile against qt5.15. SkipEmptyParts is part of Qt::.
  * Linux/cpuinfo.c: grow buffer size as needed for 12+ core CPUs (kde#384515)
  * Use safe hardcoded value for ProvidersUrl
  * Unify ksysguard cpu clock speed names
* Tue May  5 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.5.php
- Changes since 5.18.4.1:
  * Remove too strict Qt/KF5 deprecation rule
* Tue Mar 31 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.4.1:
  * Version fixed
* Tue Mar 31 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.4.php
- No code changes since 5.18.3
* Tue Mar 10 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.3.php
- Changes since 5.18.2:
  * Linux/cpuinfo.c: grow buffer size as needed for 12+ core CPUs (kde#384515)
  * Only deprecate up to target frameworks
* Tue Feb 25 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.2.php
- Changes since 5.18.1:
  * Unify ksysguard cpu clock speed names
* Tue Feb 18 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.1.php
- No code changes since 5.18.0
* Thu Feb  6 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.0.php
- No code changes since 5.17.90
* Mon Jan 27 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Fix path for chkstat (boo#1151190)
* Thu Jan 23 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build
* Thu Jan 16 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.90.php
- Changes since 5.17.5:
  * typo--
  * Remove endl. qCritical/qDebug already adds a endl.
  * Don't use nullptr as flag value
  * Move ACPI battery information from /proc/acpi to /sys
  * Revert "Move ACPI battery information from /proc/acpi to /sys"
  * Move ACPI battery information from /proc/acpi to /sys
  * Add Total/Available/Allocated memory sensors
  * Use URL with transport encryption
  * Make it compiles without deprecated method
  * Add KDEClangFormat cmake support
  * Fix ksysguard acpi cooling devices
  * Fix minor issues found by EBN
  * fix nvidia line part count
  * Fix a number of issues found by the OpenSuse security team in networkhelper
  * Add plugin showing nvidia GPU load stats
  * Make it compile without deprecated method
  * Port QLayout::setMargins to QLayout::setContentsMargins
* Tue Jan  7 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.5.php
- No code changes since 5.17.4
* Wed Dec  4 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.4.php
- Changes since 5.17.3:
  * Add DesktopEntry to notifyrc
* Tue Nov 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.3.php
- No code changes since 5.17.2
* Tue Oct 29 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.2.php
- No code changes since 5.17.1
* Tue Oct 22 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.1.php
- No code changes since 5.17.0
* Thu Oct 10 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.0.php
- Changes since 5.16.90:
  * Fix a number of issues found by the OpenSuse security team in
    networkhelper (boo#1151190)
* Thu Sep 19 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.90.php
- Changes since 5.16.5:
  * Port QLayout::setMargins to QLayout::setContentsMargins
  * Set default visibility for per-process network sensors to true
  * Replace s6_addr32 with s6_addr in the network plugin helper
  * Yet another BSD compile fix
  * Another FreeBSD compile fix
  * Try to fix building the network plugin on FreeBSD
  * Add a per-process network information plugin
  * HiDPI icon in buttons and menus
  * Linux softraid: Define _GNU_SOURCE for pipe2
  * QT_NO_NARROWING_CONVERSIONS_IN_CONNECT is already defined in ecm
  * Remove unused includes
  * Ignore files
  * Fix forward declaration
  * ksysguardd: show Mandatory Access Control (SELinux/AppArmor) context
  * ProcessList: add support for cgroups
  * ProcessList: add NoNewPrivileges
* Tue Sep  3 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.5.php
- No code changes since 5.16.4
* Tue Jul 30 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.4.php
- No code changes since 5.16.3
* Tue Jul  9 2019 fabian@ritter-vogt.de
- Update to 5.16.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.3.php
- No code changes since 5.16.2
* Thu Jul  4 2019 wbauer@tmo.at
- Update/cleanup build requirements
* Tue Jun 25 2019 fabian@ritter-vogt.de
- Update to 5.16.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.2.php
- No code changes since 5.16.1
* Tue Jun 18 2019 fabian@ritter-vogt.de
- Update to 5.16.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.1.php
- No code changes since 5.16.0
* Thu Jun  6 2019 fabian@ritter-vogt.de
- Update to 5.16.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.0.php
- Changes since 5.15.90:
  * Null pointer dereference at ksysguard
  * Move knsrc files to the new location
* Thu May 16 2019 fabian@ritter-vogt.de
- Update to 5.15.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.90.php
- Changes since 5.15.5:
  * bump Qt version to 5.12 as agreed at start of cycle
  * Port deprecated method
  * Simpe C updates to ksysguardd code
  * Reduce string objects
* Tue May  7 2019 fabian@ritter-vogt.de
- Update to 5.15.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.5.php
- No code changes since 5.15.4
* Tue Apr  2 2019 fabian@ritter-vogt.de
- Update to 5.15.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.4.php
- No code changes since 5.15.3
* Tue Mar 12 2019 fabian@ritter-vogt.de
- Update to 5.15.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.3.php
- No code changes since 5.15.2
* Tue Feb 26 2019 fabian@ritter-vogt.de
- Update to 5.15.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.2.php
- No code changes since 5.15.1
* Tue Feb 19 2019 fabian@ritter-vogt.de
- Update to 5.15.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.1.php
- No code changes since 5.15.0
* Thu Feb  7 2019 fabian@ritter-vogt.de
- Update to 5.15.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.0.php
- No code changes since 5.14.90
* Thu Jan 17 2019 fabian@ritter-vogt.de
- Update to 5.14.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.90.php
- Changes since 5.14.5:
  * bump KF5 dependency to required 5.54 as agreed at start of Plasma 5.15 cycle
  * Fix some clazy warning
  * Add missing explicit
  * Remove unused code
  * USe override. Add missing explicit
  * Use int (remove warning)
  * Fix minor typos
  * port to QStringLiteral
  * fix indentation
  * Provide option to hide menu bar for Ksysguard
* Tue Jan  8 2019 fabian@ritter-vogt.de
- Update to 5.14.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.5.php
- No code changes since 5.14.4
* Wed Nov 28 2018 fabian@ritter-vogt.de
- Update to 5.14.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.4.php
- No code changes since 5.14.3
* Tue Nov  6 2018 fabian@ritter-vogt.de
- Add David Edmundson's key to plasma.keyring
- Update to 5.14.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.3.php
- No code changes since 5.14.2
* Tue Oct 23 2018 fabian@ritter-vogt.de
- Update to 5.14.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.2.php
- No code changes since 5.14.1
* Tue Oct 16 2018 fabian@ritter-vogt.de
- Update to 5.14.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.1.php
- No code changes since 5.14.0
* Fri Oct  5 2018 fabian@ritter-vogt.de
- Update to 5.14.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.0.php
- No code changes since 5.13.90
* Sat Sep 15 2018 fabian@ritter-vogt.de
- Add tarball signature and keyring containing keys of release managers
  Jonathan Riddell and Bhushan Shah
* Thu Sep 13 2018 fabian@ritter-vogt.de
- Update to 5.13.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.90.php
- Changes since 5.13.5:
  * QT_MIN_VERSIONS is Qt 5.11 for Plasma 5.14. Agreed at kickoff meeting.  Set everywhere for clearity and consistency.
  * Add AppStream metadata
* Tue Sep  4 2018 fabian@ritter-vogt.de
- Update to 5.13.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.5.php
- Changes since 5.13.4:
  * None
* Tue Jul 31 2018 fabian@ritter-vogt.de
- Update to 5.13.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.4.php
- Changes since 5.13.3:
  * None
* Tue Jul 10 2018 fabian@ritter-vogt.de
- Update to 5.13.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.3.php
- Changes since 5.13.2:
  * None
* Tue Jun 26 2018 fabian@ritter-vogt.de
- Update to 5.13.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.2.php
- Changes since 5.13.1:
  * Fix leak of pipe FDs in MD RAID code (kde#378268)
  * Explicitly include <QDoubleValidator> to fix build with Qt 5.11
* Tue Jun 19 2018 fabian@ritter-vogt.de
- Update to 5.13.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.1.php
- Changes since 5.13.0:
  * None
* Thu Jun  7 2018 fabian@ritter-vogt.de
- Update to 5.13.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.0.php
- Changes since 5.12.90:
  * None
* Sat May 19 2018 fabian@ritter-vogt.de
- Update to 5.12.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.90.php
- Changes since 5.12.5:
  * Fix warning
  * Make some strings easier to translate
  * Explicitly include <QDoubleValidator> to fix build with Qt 5.11
  * Remove extra ';'
  * Fix some warnings
  * Use more non-deprecated KDEInstallDirs variables
  * Remove another module namespace from a Qt include
  * Remove linking with no longer set var KDE4_KDEFAKES_LIBS
  * Remove Qt includes with modula namespace
  * Use non-deprecated KDEInstallDirs variables
  * Use KF5_MIN_VERSION also for ECM, now that it's part of KF
  * Bump min cmake version to 3.0, move cmake_minimum_required to top
  * Correction with the & problem in tabs (kde#382512)
  * Use nullptr
  * Reserve vector
  * Start to make it compile with strict compile flags
- Refresh 0001-Use-run-for-ksysguardd-s-pid-file.patch
* Wed May  2 2018 fabian@ritter-vogt.de
- Update to 5.12.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.5.php
- Changes since 5.12.4:
  * None
* Tue Mar 27 2018 fabian@ritter-vogt.de
- Update to 5.12.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.4.php
- Changes since 5.12.3:
  * None
* Tue Mar  6 2018 fabian@ritter-vogt.de
- Update to 5.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.3.php
- Changes since 5.12.2:
  * Explicitly include <QDoubleValidator> to fix build with Qt 5.11
* Wed Feb 21 2018 lbeltrame@kde.org
- Update to 5.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.2.php
- Changes since 5.12.1:
  * None
- Refreshed patches:
  * 0001-Use-run-for-ksysguardd-s-pid-file.patch
* Tue Feb 13 2018 fabian@ritter-vogt.de
- Update to 5.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.1.php
- Changes since 5.12.0:
  * Require KDE Frameworks 5.42 and Qt 5.9
  * Correction with the & problem in tabs (kde#382512)
* Fri Feb  2 2018 fabian@ritter-vogt.de
- Update to 5.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.0.php
- Changes since 5.11.95:
  * None
* Mon Jan 15 2018 fabian@ritter-vogt.de
- Update to 5.11.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.95.php
- Changes since 5.11.5:
  * linux: expand 'arrayDevice' by 1 character more
  * Remove obsolete reviewboardrc file
  * fix warning comparing int with uint
  * fix warning, o is unused
  * fix warning comparing uint to int
  * replace tabs with spaces for style consistency
  * revise the tab upload dialog to direct people at the kde store
  * Add .arcconfig
  * Don't repeat work of KAboutData::setupCommandLine()
  * Group app metadata setting code
* Tue Jan  2 2018 fabian@ritter-vogt.de
- Update to 5.11.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.5.php
- Changes since 5.11.4:
  * None
* Thu Nov 30 2017 fabian@ritter-vogt.de
- Update to 5.11.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.4.php
- Changes since 5.11.3:
  * use OCS to retrieve Tabs from the KDE store (kde#338669)
* Tue Nov  7 2017 fabian@ritter-vogt.de
- Update to 5.11.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.3.php
- Changes since 5.11.2:
  * None
* Tue Oct 24 2017 fabian@ritter-vogt.de
- Update to 5.11.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.2.php
- Changes since 5.11.1:
  * None
* Tue Oct 17 2017 fabian@ritter-vogt.de
- Update to 5.11.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.1.php
- Changes since 5.11.0:
  * Try to read CPU clock from cpufreq/scaling_cur_freq instead of /proc/cpuinfo (kde#382561)
- Remove patches, now upstream:
  * 0001-Try-to-read-CPU-clock-from-cpufreq-scaling_cur_freq-.patch
* Fri Oct  6 2017 fabian@ritter-vogt.de
- Add patch to fix gathering of the CPU clock with kernel >= 4.13
  (boo#1061071, kde#382561):
  * 0001-Try-to-read-CPU-clock-from-cpufreq-scaling_cur_freq-.patch
* Thu Oct  5 2017 fabian@ritter-vogt.de
- Update to 5.11.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.0.php
- Changes since 5.10.95:
  * None
* Thu Sep 14 2017 fabian@ritter-vogt.de
- Update to 5.10.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.95.php
- Changes since 5.10.5:
  * softraid: Remove dead code and associated warning.
  * Properly check if mdraid array is active.
  * FreeBSD build fix, v4.
  * FreeBSD compile fix, try 3.
  * Fix FreeBSD build, try 2.
  * Fix build regression on FreeBSD
  * Fix compilation with strict libc (such as musl).
  * remove extra <nlist.h> include on FreeBSD
  * Use Q_DECL_OVERRIDE
* Tue Aug 22 2017 fabian@ritter-vogt.de
- Update to 5.10.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.5.php
- Changes since 5.10.4:
  * None
* Tue Jul 18 2017 fabian@ritter-vogt.de
- Update to 5.10.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.4.php
- Changes since 5.10.3:
  * None
* Tue Jun 27 2017 fabian@ritter-vogt.de
- Update to 5.10.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.3.php
- Changes since 5.10.2:
  * None
* Tue Jun 13 2017 fabian@ritter-vogt.de
- Update to 5.10.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.2.php
- Changes since 5.10.1:
  * None
* Tue Jun  6 2017 fabian@ritter-vogt.de
- Update to 5.10.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.1.php
- Changes since 5.10.0:
  * None
* Fri May 26 2017 fabian@ritter-vogt.de
- Update to 5.10.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.0.php
- Changes since 5.9.95:
  * None
* Thu May 11 2017 fabian@ritter-vogt.de
- Update to 5.9.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.95.php
- Changes since 5.9.5:
  * update ksysguard docbook
* Tue Apr 25 2017 lbeltrame@kde.org
- Update to 5.9.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.5.php
- Changes since 5.9.4:
  * None
* Tue Mar 21 2017 fabian@ritter-vogt.de
- Update to 5.9.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.4.php
- Changes since 5.9.3:
  * None
* Tue Feb 28 2017 fabian@ritter-vogt.de
- Update to 5.9.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.3.php
- Changes since 5.9.2:
  * Merge remote-tracking branch 'origin/Plasma/5.8' into Plasma/5.9
  * Fix array allocation for non-continuous cpu numbers
* Tue Feb 14 2017 fabian@ritter-vogt.de
- Update to 5.9.2
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.2.php
- Changes since 5.9.1:
  * None
* Tue Feb  7 2017 fabian@ritter-vogt.de
- Update to 5.9.1
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.1.php
- Changes since 5.9.0:
  * None
* Thu Jan 26 2017 fabian@ritter-vogt.de
- Update to 5.9.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.0.php
- Changes since 5.8.95:
  * None
* Thu Jan 12 2017 fabian@ritter-vogt.de
- Update to 5.8.95 (Plasma 5.9 Beta)
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.95.php
- Changes:
  * Use unicode codepoint instead of UTF-8 literal.
  * Add monitors for Linux memory infos dirty and writeback.
* Tue Dec 27 2016 fabian@ritter-vogt.de
- Update to 5.8.5
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.5.php
* Wed Nov 23 2016 fabian@ritter-vogt.de
- Update to 5.8.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.4.php
* Thu Nov  3 2016 fabian@ritter-vogt.de
- Introduce new _plasma5_bugfix global for more fine-tuned dependencies
* Tue Nov  1 2016 fabian@ritter-vogt.de
- Update to 5.8.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.3.php
* Tue Oct 18 2016 fabian@ritter-vogt.de
- Update to 5.8.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.2.php
* Tue Oct 11 2016 fabian@ritter-vogt.de
- Update to 5.8.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.1.php
* Wed Oct  5 2016 fabian@ritter-vogt.de
- Add Source: URL back
* Thu Sep 29 2016 fabian@ritter-vogt.de
- Update to 5.8.0
  * New LTS feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.0.php
* Wed Sep 21 2016 fabian@ritter-vogt.de
- Use %%{_plasma5_version} again, define it if needed
* Thu Sep 15 2016 fabian@ritter-vogt.de
- Update to 5.7.95 (Plasma 5.8 Beta)
  * New LTS feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.95.php
* Tue Sep 13 2016 fabian@ritter-vogt.de
- Update to 5.7.5
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.5.php
* Fri Aug 26 2016 fabian@ritter-vogt.de
- Update to 5.7.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.4.php
* Tue Aug  2 2016 hrvoje.senjan@gmail.com
- Update to 5.7.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.3.php
* Wed Jul 20 2016 hrvoje.senjan@gmail.com
- Update to 5.7.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.2.php
* Wed Jul 13 2016 hrvoje.senjan@gmail.com
- Update to 5.7.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.1.php
* Tue Jul  5 2016 wbauer@tmo.at
- Use the new %%kf5_find_lang macro to create the file list for the
  lang package
- Remove rpmlintrc file, it is not needed any more now
* Thu Jun 30 2016 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.0.php
* Sun May 15 2016 hrvoje.senjan@gmail.com
- Update to 5.6.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.4.php
* Tue Apr 19 2016 hrvoje.senjan@gmail.com
- Update to 5.6.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.3.php
* Tue Apr  5 2016 hrvoje.senjan@gmail.com
- Update to 5.6.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.2.php
* Tue Mar 29 2016 hrvoje.senjan@gmail.com
- Update to 5.6.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.1.php
* Sun Mar 20 2016 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.0.php
* Tue Mar  1 2016 hrvoje.senjan@gmail.com
- Update to 5.5.5 (boo#968966)
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.5.php
* Tue Jan 26 2016 hrvoje.senjan@gmail.com
- Update to 5.5.4:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.4.php
* Wed Jan  6 2016 hrvoje.senjan@gmail.com
- Update to 5.5.3:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.3.php
* Tue Dec 22 2015 hrvoje.senjan@gmail.com
- Update to 5.5.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.2.php
* Tue Dec 15 2015 hrvoje.senjan@gmail.com
- Update to 5.5.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.1.php
* Sat Dec 12 2015 hrvoje.senjan@gmail.com
- Update to 5.5.0:
  * For more details please see:
    https://dot.kde.org/2015/12/08/plasma-55-beautiful-new-artwork
- Move to cmake(...) BuildRequires where possible
* Mon Nov 16 2015 hrvoje.senjan@gmail.com
- Drop oxygen-icon-theme Requires
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.4.3 (boo#955068):
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.3.php
* Sun Oct  4 2015 hrvoje.senjan@gmail.com
- Update to 5.4.2:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.2.php
* Thu Sep 10 2015 hrvoje.senjan@gmail.com
- Update to 5.4.1:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.1.php
* Mon Aug 24 2015 hrvoje.senjan@gmail.com
- Update to 5.4.0:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.0.php
* Sun Aug 16 2015 hrvoje.senjan@gmail.com
- Update to 5.3.95 aka 5.4 beta:
  This release of Plasma brings many nice touches for our users
  such as much improved high DPI support, KRunner auto-completion
  and many new beautiful Breeze icons. It also lays the ground for
  the future with a tech preview of Wayland session available.
  We're shipping a few new components such as an Audio Volume
  Plasma Widget, monitor calibration tool and the User Manager
  tool comes out beta.
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.95.php
* Sun Jul 26 2015 hrvoje.senjan@gmail.com
- Fix Oboletes/Provides versions regarding Leap versioning
* Sun Jun 28 2015 hrvoje.senjan@gmail.com
- Update to 5.3.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.2.php
* Fri May 22 2015 hrvoje.senjan@gmail.com
- Update to 5.3.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.1.php
* Thu Apr 23 2015 hrvoje.senjan@gmail.com
- Update to 5.3 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.0.php
- Obsolete kdebase4-workspace-ksysguardd for openSUSE > 13.2
* Sat Apr 11 2015 hrvoje.senjan@gmail.com
- Update to 5.2.95 aka 5.3 beta:
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.95.php
- Update required Qt version to 5.4.0
* Thu Mar 19 2015 hrvoje.senjan@gmail.com
- Update to 5.2.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.2.php
- Drop 0001-Register-KSysguard-to-DBus.patch, merged upstream
* Fri Mar 13 2015 hrvoje.senjan@gmail.com
- Add 0001-Register-KSysguard-to-DBus.patch from upstream (kde#344595)
* Fri Feb 20 2015 hrvoje.senjan@gmail.com
- Update to 5.2.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.1.php
* Mon Jan 26 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.0.php
* Tue Jan 13 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Beta aka 5.1.95:
  * Undo changes to Plasma desktop layout
  * Smarter sorting of results in KRunner
  * Breeze window decoration theme adds a new look to your
    desktop and is now used by default
  * New white mouse cursor theme for Breeze.
  * New plasma widgets: 15 puzzle, web browser, show desktop
  * Over 300 bugs fixed throughout Plasma modules.
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.95.php
* Thu Dec 11 2014 hrvoje.senjan@gmail.com
- Update to 5.1.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.2.php
* Thu Nov  6 2014 hrvoje.senjan@gmail.com
- Update to 5.1.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.1.php
* Sat Oct 25 2014 hrvoje.senjan@gmail.com
- Recommend lang subpackage
* Thu Oct  9 2014 hrvoje.senjan@gmail.com
- Update to 5.1 Final:
  * Bugfixes since RC1
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.0.php
* Fri Sep 26 2014 hrvoje.senjan@gmail.com
- Update to 5.0.95:
  * Use non-deprecated location for kxmlgui configuration
- Install translations
- Add rpmlintrc file for file-not-in-%%lang warnings: we don't use
  find_lang macro as it doesn't searches in subdirectories
* Thu Sep 25 2014 hrvoje.senjan@gmail.com
- Drop %%insserv_prereq preqeuires, not relevant for systemd service
* Wed Sep  3 2014 hrvoje.senjan@gmail.com
- Add ksysguardd systemd service
- Add 0001-Use-run-for-ksysguardd-s-pid-file.patch, so daemon uses
  /run instead of /var/run
* Mon Aug 11 2014 hrvoje.senjan@gmail.com
- Update to 5.0.1
  * Bugfix release
- Added libksysguard5-helper Requires
* Fri Jul 25 2014 hrvoje.senjan@gmail.com
- Mark license as GPL-2.0
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Plasma 5.0 Final
* Thu Jul  3 2014 hrvoje.senjan@gmail.com
- Update to 4.98.0
  * Plasma 5 RC release
* Wed Jun 11 2014 hrvoje.senjan@gmail.com
- Activate ksysguard5 package
